##  SAP Cloud Solutions Modeling Perspectives
SAP's cloud portfolio, mainly offered as Software-as-a-Service (SaaS), aligns with the evolving architecture of ERP landscapes. Offered through the SAP Business Technology Platform (BTP), it provides a robust platform and integration for various business needs. Key examples of SAP cloud solutions include:
  * At the core are Cloud ERP solutions: SAP S/4HANA Cloud Private Edition and SAP S/4HANA Cloud Public Edition.
  * A portfolio of integrated SAP and ecosystem applications: HCM, Spend, CRM, Business Transformation, SAP Ariba, SAP Concur, SAP SuccessFactors, SAP Signavio, and SAP LeanIX.
  * Foundational technology for integration and extension: SAP Business Technology Platform (SAP BTP).
